# CAT: an automated data cleaning tool for code summarization datasets

This is a package for  `Are We Built on the Rock? On the Importance of Data Preprocessing for Code Summarization`.

Our project is public at: `<https://github.com/BuiltOntheRock/FSE22_BuiltOntheRock>`_
